package org.vraptor.component;

import java.util.Collection;
import java.util.List;

import org.vraptor.LogicRequest;
import org.vraptor.annotations.In;
import org.vraptor.annotations.Out;
import org.vraptor.interceptor.InterceptorClass;
import org.vraptor.introspector.FieldReadParameter;
import org.vraptor.scope.ScopeType;

/**
 * A component wrapper.
 * 
 * @author Guilherme Silveira
 */
public class ComponentWrapper implements ComponentType {

	private ComponentType type;

	public ComponentWrapper(ComponentType component) {
		this.type = component;
	}

	public List<FieldAnnotation<In>> getInAnnotations() {
		return type.getInAnnotations();
	}

	public List<InterceptorClass> getInterceptors() {
		return type.getInterceptors();
	}

	public LogicMethod getLogic(String key) throws LogicNotFoundException {
		return type.getLogic(key);
	}

	public String getName() {
		return type.getName();
	}

	public List<FieldAnnotation<Out>> getOutAnnotations() {
		return type.getOutAnnotations();
	}

	public List<FieldReadParameter> getReadParameters() {
		return type.getReadParameters();
	}

	public Collection<LogicMethod> getLogics() {
		return type.getLogics();
	}

	public Class getComponentClass() {
		return type.getComponentClass();
	}

	public Object newInstance(LogicRequest request)
			throws ComponentInstantiationException {
		return type.newInstance(request);
	}

	public ScopeType getScope() {
		return type.getScope();
	}

	public String getKey() {
		return type.getKey();
	}

	public String getDestroyLogicName() {
		return type.getDestroyLogicName();
	}

}
